<template>
  <div class="app-container">
    <el-form
      :model="queryParams"
      ref="queryForm"
      size="small"
      :inline="true"
      v-show="showSearch"
      label-width="68px"
    >
      <el-form-item label="体检号" prop="tjNum">
        <el-input
          v-model="queryParams.tjNum"
          placeholder="请输入体检号"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="就诊号" prop="cardId">
        <el-input
          v-model="queryParams.cardId"
          placeholder="请输入就诊号"
          clearable
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>
      <el-form-item label="打印时间" prop="createTimeList">
        <el-date-picker
          v-model="createTimeList"
          type="datetimerange"
          align="right"
          :picker-options="pickerOptions"
          style="width: 300px"
          start-placeholder="开始日期"
          end-placeholder="结束日期"
          :default-time="['00:00:00', '23:59:00']"
          format="yyyy-MM-dd HH:mm"
          value-format="yyyy-MM-dd HH:mm"
          @change="dateChangebirthday1"
        >
        </el-date-picker>
      </el-form-item>

      <el-form-item>
        <el-button
          type="primary"
          icon="el-icon-search"
          size="mini"
          @click="handleQuery"
          >搜索</el-button
        >
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery"
          >重置</el-button
        >
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <!-- <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['system:dyjl:add']"
          >新增
        </el-button>
      </el-col> -->
      <!--   <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['system:dyjl:edit']"
          >修改
        </el-button>
      </el-col> -->
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['system:dyjl:remove']"
          >删除
        </el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
          @click="handleExport"
          v-hasPermi="['system:dyjl:export']"
          >导出
        </el-button>
      </el-col>
      <right-toolbar
        :showSearch.sync="showSearch"
        @queryTable="getList"
      ></right-toolbar>
    </el-row>

    <el-table
      v-loading="loading"
      :data="dyjlList"
      @selection-change="handleSelectionChange"
    >
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="序号" align="center" width="55">
        <template v-slot="scope">
          {{ scope.$index + 1 }}
        </template>
      </el-table-column>
      <el-table-column label="体检人" align="center" prop="hzxm" />
      <el-table-column label="体检号" align="center" prop="tjNum" />
      <el-table-column label="就诊号" align="center" prop="cardId" />
      <el-table-column label="打印类型" align="center" prop="dylx">
        <template slot-scope="scope">
          <span v-if="scope.row.dylx == '0'">导检单</span>
          <span v-if="scope.row.dylx == '1'">补录单</span>
        </template>
      </el-table-column>
      <el-table-column label="打印次数" align="center" prop="dycs" />
      <el-table-column label="打印时间" align="center" prop="dysj" />
      <el-table-column label="打印人" align="center" prop="createBy" />
      <el-table-column
        label="操作"
        align="center"
        class-name="small-padding fixed-width"
      >
        <template slot-scope="scope">
          <!--  <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['system:dyjl:edit']"
            >修改
          </el-button> -->
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['system:dyjl:remove']"
            >删除
          </el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total > 0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改体检导检单打印记录对话框 -->
    <!-- <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
      <el-form ref="form" :model="form" :rules="rules" label-width="80px">
        <el-form-item label="${comment}" prop="tjNum">
          <el-input v-model="form.tjNum" placeholder="请输入${comment}" />
        </el-form-item>
        <el-form-item label="${comment}" prop="cardId">
          <el-input v-model="form.cardId" placeholder="请输入${comment}" />
        </el-form-item>
        <el-form-item label="打印次数" prop="dycs">
          <el-input v-model="form.dycs" placeholder="请输入打印次数" />
        </el-form-item>
        <el-form-item label="${comment}" prop="deleted">
          <el-input v-model="form.deleted" placeholder="请输入${comment}" />
        </el-form-item>
      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog> -->
  </div>
</template>

<script>
import {
  listDyjl,
  getDyjl,
  delDyjl,
  addDyjl,
  updateDyjl,
  exportDyjl
} from "@/api/system/dyjl";
import { getNewDateList } from "@/api/hosp/order";
import moment from "moment";

export default {
  name: "Dyjl",
  data() {
    return {
      // 遮罩层
      loading: true,
      createTimeList: "",
      startTime: "",
      datetimerange: [],
      // 选中数组
      ids: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 体检导检单打印记录表格数据
      dyjlList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        tjNum: null,
        cardId: null,
        dysj: null,
        deleted: null,
        beginTime: null,
        endTime: null,
        createTime: null,
      },
      // 表单参数
      form: {},
      pickerOptions: {
        shortcuts: [
          {
            text: "最近一周",
            onClick(picker) {
              const end = new Date();
              const start = new Date();
              start.setTime(start.getTime() - 3600 * 1000 * 24 * 7);
              picker.$emit("pick", [start, end]);
            },
          },
          {
            text: "最近一个月",
            onClick(picker) {
              const end = new Date();
              const start = new Date();
              start.setTime(start.getTime() - 3600 * 1000 * 24 * 30);
              picker.$emit("pick", [start, end]);
            },
          },
          {
            text: "最近三个月",
            onClick(picker) {
              const end = new Date();
              const start = new Date();
              start.setTime(start.getTime() - 3600 * 1000 * 24 * 90);
              picker.$emit("pick", [start, end]);
            },
          },
        ],
      },
      // 表单校验
      /* rules: {
        deleted: [
          {
            required: true,
            message: "$comment不能为空",
            trigger: "blur",
          },
        ],
      }, */
    };
  },
  created() {
    // this.getList();
    this.getdate();
  },
  methods: {
    getdate() {
      getNewDateList().then((res) => {
        this.createTimeList = [
          moment(res.data).format("YYYY-MM-DD 00:00:00"),
          moment(res.data).format("YYYY-MM-DD 23:59:00"),
        ];
        this.getList();
      });
    },
    getLocalTime(nS) {
      var time = new Date(nS);
      var y = time.getFullYear();
      var m = time.getMonth() + 1;
      var d = time.getDate();
      return y + "-" + this.add0(m) + "-" + this.add0(d);
    },
    getNowTime() {
      var curDate = new Date().getTime();
      var dayNum = 7 * 24 * 3600 * 1000;
      var threeDays = curDate - dayNum;
      var sDay = this.getLocalTime(threeDays);
      var end = this.getLocalTime(curDate);
      this.createTimeList = [sDay, end];
    },
    add0(m) {
      return m < 10 ? "0" + m : m;
    },
    dateChangebirthday1(val) {
        this. startTime= val;
    },
    /** 查询体检导检单打印记录列表 */
    getList() {
        if (this.startTime) {
        this.queryParams.beginTime = this.startTime[0];
        this.queryParams.endTime = this.startTime[1];
      } else if (this.createTimeList) {
        this.queryParams.beginTime = this.createTimeList[0];
        this.queryParams.endTime = this.createTimeList[1];
      } else if (this.createTimeList == null) {
        this.queryParams.beginTime = null;
        this.queryParams.endTime = null;
      }
      this.loading = true;
      listDyjl(this.queryParams).then((response) => {
        this.dyjlList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        tjNum: null,
        cardId: null,
        dycs: null,
        createTime: null,
        createBy: null,
        updateTime: null,
        updateBy: null,
        deleted: null,
        beginTime:null,
        endTime:null
      };
      this.resetForm("form");
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.startTime = [];
      this.createTimeList = [];
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map((item) => item.id);
      this.single = selection.length !== 1;
      this.multiple = !selection.length;
    },
    /** 新增按钮操作 */
    /* handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加体检导检单打印记录";
    }, */
    /** 修改按钮操作 */
    /*  handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids;
      getDyjl(id).then((response) => {
        this.form = response.data;
        this.open = true;
        this.title = "修改体检导检单打印记录";
      });
    }, */
    /* submitForm() {
      this.$refs["form"].validate((valid) => {
        if (valid) {
          if (this.form.id != null) {
            updateDyjl(this.form).then((response) => {
              this.$modal.msgSuccess("修改成功");
              this.kjbqopen = false;
              this.getList();
            });
          } else {
            addDyjl(this.form).then((response) => {
              this.$modal.msgSuccess("新增成功");
              this.kjbqopen = false;
              this.getList();
            });
          }
        }
      });
    }, */
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      this.$modal
        .confirm('是否确认删除？')
        .then(function () {
          return delDyjl(ids);
        })
        .then(() => {
          this.getList();
          this.$modal.msgSuccess("删除成功");
        })
        .catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      console.log(this.ids,5656);
      
      this.download(
        "system/dyjl/export",
        {
          ...this.queryParams,
          ids:this.ids
        },
        `dyjl_${new Date().getTime()}.xlsx`
      );
    },
  },
};
</script>
